@@ -5,6 +5,7 @@ module Text.Email.Parser
     , localPart
     , domainPart
     , EmailAddress
+    , unsafeEmailAddress
     , toByteString
     )
 where
@@ -25,6 +26,13 @@ import qualified Text.Read as Read
 data EmailAddress = EmailAddress ByteString ByteString
     deriving (Eq, Ord, Data, Typeable, Generic)
 
+-- | Creates an email address without validating it.
+--   You should only use this when reading data from
+--   somewhere it has already been validated (e.g. a
+--   database).
+unsafeEmailAddress :: ByteString -> ByteString -> EmailAddress
+unsafeEmailAddress = EmailAddress
+
 instance Show EmailAddress where
     show = show . toByteString
 
